@@ -15,18 +15,18 @@ You should have received a copy of the GNU General Public License along with
 this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
-use clap::Clap;
+use clap::Parser;
 
 /// Get system resources overview in 50 characters
 /// For usage details, try --help
 ///
 /// Understanding the output:
+///     Memory Usage{n}
+///     CPU Information (usage and optionally frequency) {n}
+///     Temperature for the hottest sensor{n}
+///     Ping (only available in the long running log/watch mode)
 ///
-///   M: Memory Usage
-///   C: CPU Usage and Frequency
-///   T: Temperature for the hottest sensor
-///   P: Ping
-#[derive(Clap)]
+#[derive(Parser, Debug)]
 #[clap(verbatim_doc_comment)]
 #[clap(version = env!("CARGO_PKG_VERSION"), author = "Rohan Jain")]
 pub struct Config {
@@ -85,4 +85,8 @@ pub struct Config {
     /// host to use for testing the ping
     #[clap(long, default_value = "1.0.0.1")]
     pub ping_host: String,
+
+    /// show CPU frequency
+    #[clap(short, long)]
+    pub frequency: bool,
 }
