@@ -19,7 +19,15 @@ use super::colors::colorize;
 use super::config::Config;
 use sysinfo::{ProcessorExt, System, SystemExt};
 
-pub fn usage(config: &Config, system: &System) -> String {
+pub fn overview(config: &Config, system: &System) -> String {
+    if config.frequency {
+        format!("{} @ {}", usage(config, system), frequency(system))
+    } else {
+        usage(config, system)
+    }
+}
+
+fn usage(config: &Config, system: &System) -> String {
     let processor = system.global_processor_info();
 
     format!(
@@ -32,6 +40,6 @@ pub fn usage(config: &Config, system: &System) -> String {
     )
 }
 
-pub fn frequency(system: &System) -> String {
+fn frequency(system: &System) -> String {
     format!("{:4} MHz", system.global_processor_info().frequency())
 }
