@@ -15,7 +15,7 @@ You should have received a copy of the GNU General Public License along with
 this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
-use clap::Clap;
+use clap::Parser;
 use std::io::stdout;
 use std::io::Result;
 use std::io::Write;
@@ -42,10 +42,9 @@ struct State {
 
 fn line(state: &State) -> String {
     format!(
-        "M:{} | C:{} @ {} | T:{} | P: {}",
+        " {} {} {}   {}",
         memory::usage(&state.config, &state.system),
-        cpu::usage(&state.config, &state.system),
-        cpu::frequency(&state.system),
+        cpu::overview(&state.config, &state.system),
         sensors::temperature(&state.config, &state.system),
         state.ping.current()
     )
